from setuptools import setup, find_packages
setup(name="HttpMessageHandler",
      version="0.1.2",
      packages=find_packages(where="."),
      install_requires=['MessageBus==1.0.1',
                        'HttpClient==0.1.1',
                        'enum;python_version<="2.7"',
                        'typing;python_version<="2.7"'],
      url="http://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br")
